@@ -24,8 +24,8 @@ module grafic_io
   use grafic_types
   implicit none
 !  integer, parameter :: nblock = 10
-  integer, parameter :: RECORD_FLAG=4 !bytes 
-  
+  integer, parameter :: RECORD_FLAG=4 !bytes
+
   type taille
      integer :: nx
      integer :: ny
@@ -53,13 +53,13 @@ module grafic_io
 
 contains
 
-  
-  ! This routine write a fftw_mpi slice of a cube 
+
+  ! This routine write a fftw_mpi slice of a cube
   ! This slice has interior dimension nx, exterior nz.
   ! Beware that interior dimension is padded: nx <- 2(nx/2+1)
   ! Padded region will not be written.
   subroutine grafic_write_double(buffer,local_nz,local_z_start,ny,nx,filename,padding_in, white_in)
-    
+
     ! Arguments
     implicit none
     include 'mpif.h'
@@ -80,37 +80,36 @@ contains
     integer :: i,j,k,myid,ierr
     logical :: padding, white
 
-
     padding=.false.
     white=.false.
     if (present(padding_in)) padding = padding_in
     !if (present(padding_in)) write(*,*) 'padding is on'
     if (present(white_in)) white = white_in
-    ! 2*4 for leading and trailing record sizes 
+    ! 2*4 for leading and trailing record sizes
     n2x = 2*(nx/2+1)
     if (padding) then
        !write(*,*) 'padding is true in grafic_write'
        allocate(tampon(ny*n2x))
-       taille_tampon = ny*n2x*sp ! in bytes
+       taille_tampon = ny*n2x*sp_bytes ! in bytes
     else
        allocate(tampon(ny*nx))
-       taille_tampon = ny*nx*sp ! in bytes
+       taille_tampon = ny*nx*sp_bytes ! in bytes
     endif
 
     if (white) then
        offset = 4*4 + 2*RECORD_FLAG
     else
-       offset = 3*4+8*sp + 2*RECORD_FLAG ! First record
+       offset = 3*4+8*sp_bytes + 2*RECORD_FLAG ! First record
     endif
 
     if (padding) then
-       offset = offset + local_z_start*int(ny*n2x*sp + 2*RECORD_FLAG,8)
+       offset = offset + local_z_start*int(ny*n2x*sp_bytes + 2*RECORD_FLAG,8)
     else
-       offset = offset + local_z_start*int(ny*nx*sp + 2*RECORD_FLAG,8)
+       offset = offset + local_z_start*int(ny*nx*sp_bytes + 2*RECORD_FLAG,8)
     endif
 
     do k=1,local_nz
-       
+
        index2=1
        ! This loop to (eventually) get rid of fftw padding zone
        if (padding) then
@@ -136,9 +135,9 @@ contains
             & ,offset,taille_tampon)
        offset = offset+RECORD_FLAG
        if (padding) then
-          length = ny*n2x*sp
+          length = ny*n2x*sp_bytes
        else
-          length = ny*nx*sp
+          length = ny*nx*sp_bytes
        endif
        call f77_parallel_write(trim(filename),len_trim(filename), length, &
             & offset, tampon)
@@ -153,9 +152,9 @@ contains
     deallocate(tampon)
 
   end subroutine grafic_write_double
-       
+
   subroutine grafic_write_single(buffer,local_nz,local_z_start,ny,nx,filename,padding_in, white_in)
-    
+
     ! Arguments
     implicit none
     include 'mpif.h'
@@ -183,31 +182,31 @@ contains
     if (present(padding_in)) padding = padding_in
     !if (present(padding_in)) write(*,*) 'padding is on'
     if (present(white_in)) white = white_in
-    ! 2*4 for leading and trailing record sizes 
+    ! 2*4 for leading and trailing record sizes
     n2x = 2*(nx/2+1)
     if (padding) then
        !write(*,*) 'padding is true in grafic_write'
        allocate(tampon(ny*n2x))
-       taille_tampon = ny*n2x*sp ! in bytes
+       taille_tampon = ny*n2x*sp_bytes ! in bytes
     else
        allocate(tampon(ny*nx))
-       taille_tampon = ny*nx*sp ! in bytes
+       taille_tampon = ny*nx*sp_bytes ! in bytes
     endif
 
     if (white) then
        offset = 4*4 + 2*RECORD_FLAG
     else
-       offset = 3*4+8*sp + 2*RECORD_FLAG ! First record
+       offset = 3*4+8*sp_bytes + 2*RECORD_FLAG ! First record
     endif
 
     if (padding) then
-       offset = offset + local_z_start*int(ny*n2x*sp + 2*RECORD_FLAG,8)
+       offset = offset + local_z_start*int(ny*n2x*sp_bytes + 2*RECORD_FLAG,8)
     else
-       offset = offset + local_z_start*int(ny*nx*sp + 2*RECORD_FLAG,8)
+       offset = offset + local_z_start*int(ny*nx*sp_bytes + 2*RECORD_FLAG,8)
     endif
 
     do k=1,local_nz
-       
+
        index2=1
        ! This loop to (eventually) get rid of fftw padding zone
        if (padding) then
@@ -233,9 +232,9 @@ contains
             & ,offset,taille_tampon)
        offset = offset+RECORD_FLAG
        if (padding) then
-          length = ny*n2x*sp
+          length = ny*n2x*sp_bytes
        else
-          length = ny*nx*sp
+          length = ny*nx*sp_bytes
        endif
        call f77_parallel_write(trim(filename),len_trim(filename), length, &
             & offset, tampon)
@@ -273,15 +272,16 @@ contains
     logical :: padding
     logical :: white
 
+
     padding = .false.
     white = .false.
     if (present(padding_in)) padding = padding_in
     if (present(white_in)) white = white_in
-    ! 2*4 for leading and trailing record sizes 
+    ! 2*4 for leading and trailing record sizes
     n2x = 2*(nx/2+1)
     if (padding) then
        allocate(tampon(ny*n2x))
-    else 
+    else
        allocate(tampon(ny*nx))
     endif
     taille_tampon = 0
@@ -289,39 +289,39 @@ contains
     if (white) then
        offset = 4*4 + 2*RECORD_FLAG
     else
-       offset = 3*4+8*sp + 2*RECORD_FLAG ! First record
+       offset = 3*4+8*sp_bytes + 2*RECORD_FLAG ! First record
     endif
     if (padding) then
-       offset = offset + local_z_start*int(ny*n2x*sp + 2*RECORD_FLAG,8)
-    else 
-       offset = offset + local_z_start*int(ny*nx*sp+2*RECORD_FLAG,8)
+       offset = offset + local_z_start*int(ny*n2x*sp_bytes + 2*RECORD_FLAG,8)
+    else
+       offset = offset + local_z_start*int(ny*nx*sp_bytes+2*RECORD_FLAG,8)
     endif
 
     do k=1,local_nz
-       
+
        length = RECORD_FLAG
        ! First read f... Fortran record length
        call f77_parallel_read(trim(filename),len_trim(filename), length &
             & ,offset,taille_tampon)
        if (padding) then
-           if (taille_tampon /= ny*n2x*sp) then
+           if (taille_tampon /= ny*n2x*sp_bytes) then
              print*,'Record size ',taille_tampon,' is different from expected', &
-                  & ny*n2x*sp
+                  & ny*n2x*sp_bytes
              stop
           endif
        else
-           if (taille_tampon /= ny*nx*sp) then
+           if (taille_tampon /= ny*nx*sp_bytes) then
              print*,'Record size ',taille_tampon,' is different from expected', &
-                  & ny*nx*sp
+                  & ny*nx*sp_bytes
              stop
           endif
        endif
        offset = offset+RECORD_FLAG
 
        if (padding) then
-          length = ny*n2x*sp
-       else 
-          length = ny*nx*sp
+          length = ny*n2x*sp_bytes
+       else
+          length = ny*nx*sp_bytes
        endif
        call f77_parallel_read(trim(filename),len_trim(filename), length, &
             & offset, tampon)
@@ -379,15 +379,16 @@ contains
     logical :: padding
     logical :: white
 
+
     padding = .false.
     white = .false.
     if (present(padding_in)) padding = padding_in
     if (present(white_in)) white = white_in
-    ! 2*4 for leading and trailing record sizes 
+    ! 2*4 for leading and trailing record sizes
     n2x = 2*(nx/2+1)
     if (padding) then
        allocate(tampon(ny*n2x))
-    else 
+    else
        allocate(tampon(ny*nx))
     endif
     taille_tampon = 0
@@ -395,39 +396,39 @@ contains
     if (white) then
        offset = 4*4 + 2*RECORD_FLAG
     else
-       offset = 3*4+8*sp + 2*RECORD_FLAG ! First record
+       offset = 3*4+8*sp_bytes + 2*RECORD_FLAG ! First record
     endif
     if (padding) then
-       offset = offset + local_z_start*int(ny*n2x*sp + 2*RECORD_FLAG,8)
-    else 
-       offset = offset + local_z_start*int(ny*nx*sp+2*RECORD_FLAG,8)
+       offset = offset + local_z_start*int(ny*n2x*sp_bytes + 2*RECORD_FLAG,8)
+    else
+       offset = offset + local_z_start*int(ny*nx*sp_bytes+2*RECORD_FLAG,8)
     endif
 
     do k=1,local_nz
-       
+
        length = RECORD_FLAG
        ! First read f... Fortran record length
        call f77_parallel_read(trim(filename),len_trim(filename), length &
             & ,offset,taille_tampon)
        if (padding) then
-           if (taille_tampon /= ny*n2x*sp) then
+           if (taille_tampon /= ny*n2x*sp_bytes) then
              print*,'Record size ',taille_tampon,' is different from expected', &
-                  & ny*n2x*sp
+                  & ny*n2x*sp_bytes
              stop
           endif
        else
-           if (taille_tampon /= ny*nx*sp) then
+           if (taille_tampon /= ny*nx*sp_bytes) then
              print*,'Record size ',taille_tampon,' is different from expected', &
-                  & ny*nx*sp
+                  & ny*nx*sp_bytes
              stop
           endif
        endif
        offset = offset+RECORD_FLAG
 
        if (padding) then
-          length = ny*n2x*sp
-       else 
-          length = ny*nx*sp
+          length = ny*n2x*sp_bytes
+       else
+          length = ny*nx*sp_bytes
        endif
        call f77_parallel_read(trim(filename),len_trim(filename), length, &
             & offset, tampon)
@@ -467,7 +468,7 @@ contains
 
 
   subroutine grafic_read_header(filename,head_taille,head_cosmo)
-    
+
     type(taille), intent(out) :: head_taille
     type(cosmo), intent(out) :: head_cosmo
     character(len=128), intent(in) :: filename
@@ -488,7 +489,7 @@ contains
   end subroutine grafic_read_header
 
   subroutine grafic_read_header_white(filename,nx,ny,nz,iseed)
-    
+
     integer, intent(out) :: nx,ny,nz,iseed
     character(len=128), intent(in) :: filename
     logical :: ok
@@ -504,9 +505,9 @@ contains
     close(2)
 
   end subroutine grafic_read_header_white
-  
+
   subroutine grafic_write_header(filename,head_taille,head_cosmo)
-    
+
     type(taille), intent(in) :: head_taille
     type(cosmo), intent(in) :: head_cosmo
     character(len=128), intent(in) :: filename
@@ -520,7 +521,7 @@ contains
   end subroutine grafic_write_header
 
   subroutine grafic_write_header_white(filename,nx,ny,nz,iseed)
-    
+
     integer, intent(in) :: nx,ny,nz,iseed
     character(len=128), intent(in) :: filename
 
@@ -530,9 +531,5 @@ contains
 
   end subroutine grafic_write_header_white
 
-       
+
 end module grafic_io
-
-
-  
-    
