@@ -180,12 +180,12 @@ program grafic1
      print*,'   or enter -boxlength in Mpc/h'
      print*,'   i.e. dx in Mpc if > 0, or -boxlength in Mpc/h if < 0'
      read(*,*) dx
-     print*, dx
+     write(*,'(f15.8)') dx
   endif
   call mpi_bcast(dx,1,mpi_real,0,mpi_comm_world,ierr)
   if (dx.lt.0.0) then
      dx=-dx*100./(h0*nx)
-     if (myid==0) print*,'  dx=',dx,' Mpc'
+     if (myid==0) write(*,'(a,f15.8,a)') '  dx=',dx,' Mpc'
   end if
 
   !  Set astart based on smallest grid spacing.
@@ -233,9 +233,9 @@ program grafic1
 !!$       &                         dxr,1.0d-7)
   sigma=sqrt(sigma)
   if (myid==0) then
-     print*,'Scaling initial conditions to starting a=',astart
-     print*,'  when sigma(delta) at ultimate refinement scale=' &
-          &          ,real(sigma)
+     write(*,'(a,es15.8)') 'Scaling initial conditions to starting a=',astart
+     write(*,'(a,es15.8)') '  when sigma(delta) at ultimate refinement scale=' &
+          &  ,real(sigma)
   endif
   !sigmadispl=2.0*twopi*rombin(dsigmadispl,0.0d0,0.5d0*twopi/dxr,1.0d-7)
 !!$  sigmadispl=2.0*twopi* &
@@ -257,7 +257,7 @@ program grafic1
   !  vfact = dln(D+)/dtau where tau=conformal time.
   vfact=fomega(astart,omegam,omegav) &
        &       *h0*dladt(astart,omegam,omegav)/astart
-  if (myid==0) write(*,*)'vfact=',vfact
+  if (myid==0) write(*,'(a,es15.8)') 'vfact=',vfact
   !
   !  Now set output parameters.  There are two cases:
   !  hanning=T: no further refinement.
